@@ -8,7 +8,7 @@ from songpy.utils.transpose import transpose_by_semitones
 
 PREPROCESSORS_CHAIN = []
 SONG_PART_MARKERS = [
-    "^[0-9]\\.\\s*",
+    "^[0-9]+\\.\\s*",
     "^ref(ren|((\\.)?)):?\\s*"
 ]
 
